# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/error_code.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/error_code.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/common/proto/error_code.proto\x12\rapollo.common\"I\n\x08StatusPb\x12\x30\n\nerror_code\x18\x01 \x01(\x0e\x32\x18.apollo.common.ErrorCode:\x02OK\x12\x0b\n\x03msg\x18\x02 \x01(\t*\x99\x08\n\tErrorCode\x12\x06\n\x02OK\x10\x00\x12\x12\n\rCONTROL_ERROR\x10\xe8\x07\x12\x17\n\x12\x43ONTROL_INIT_ERROR\x10\xe9\x07\x12\x1a\n\x15\x43ONTROL_COMPUTE_ERROR\x10\xea\x07\x12\x18\n\x13\x43ONTROL_ESTOP_ERROR\x10\xeb\x07\x12\x1a\n\x15PERFECT_CONTROL_ERROR\x10\xec\x07\x12\x11\n\x0c\x43\x41NBUS_ERROR\x10\xd0\x0f\x12\x1a\n\x15\x43\x41N_CLIENT_ERROR_BASE\x10\xb4\x10\x12(\n#CAN_CLIENT_ERROR_OPEN_DEVICE_FAILED\x10\xb5\x10\x12\x1f\n\x1a\x43\x41N_CLIENT_ERROR_FRAME_NUM\x10\xb6\x10\x12!\n\x1c\x43\x41N_CLIENT_ERROR_SEND_FAILED\x10\xb7\x10\x12!\n\x1c\x43\x41N_CLIENT_ERROR_RECV_FAILED\x10\xb8\x10\x12\x17\n\x12LOCALIZATION_ERROR\x10\xb8\x17\x12\x1b\n\x16LOCALIZATION_ERROR_MSG\x10\x9c\x18\x12\x1d\n\x18LOCALIZATION_ERROR_LIDAR\x10\x80\x19\x12\x1d\n\x18LOCALIZATION_ERROR_INTEG\x10\xe4\x19\x12\x1c\n\x17LOCALIZATION_ERROR_GNSS\x10\xc8\x1a\x12\x15\n\x10PERCEPTION_ERROR\x10\xa0\x1f\x12\x18\n\x13PERCEPTION_ERROR_TF\x10\xa1\x1f\x12\x1d\n\x18PERCEPTION_ERROR_PROCESS\x10\xa2\x1f\x12\x15\n\x10PERCEPTION_FATAL\x10\xa3\x1f\x12\x1a\n\x15PERCEPTION_ERROR_NONE\x10\xa4\x1f\x12\x1d\n\x18PERCEPTION_ERROR_UNKNOWN\x10\xa5\x1f\x12\x15\n\x10PREDICTION_ERROR\x10\x88\'\x12\x13\n\x0ePLANNING_ERROR\x10\xf0.\x12\x1d\n\x18PLANNING_ERROR_NOT_READY\x10\xf1.\x12\x15\n\x10HDMAP_DATA_ERROR\x10\xd8\x36\x12\x12\n\rROUTING_ERROR\x10\xc0>\x12\x1a\n\x15ROUTING_ERROR_REQUEST\x10\xc1>\x12\x1b\n\x16ROUTING_ERROR_RESPONSE\x10\xc2>\x12\x1c\n\x17ROUTING_ERROR_NOT_READY\x10\xc3>\x12\x11\n\x0c\x45ND_OF_INPUT\x10\xa8\x46\x12\x15\n\x10HTTP_LOGIC_ERROR\x10\x90N\x12\x17\n\x12HTTP_RUNTIME_ERROR\x10\x91N\x12\x17\n\x12RELATIVE_MAP_ERROR\x10\xf8U\x12\x1b\n\x16RELATIVE_MAP_NOT_READY\x10\xf9U\x12\x16\n\x11\x44RIVER_ERROR_GNSS\x10\xe0]\x12\x1a\n\x15\x44RIVER_ERROR_VELODYNE\x10\xc8\x65\x12\x17\n\x12STORYTELLING_ERROR\x10\xb0m'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='apollo.common.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_ERROR', index=1, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_INIT_ERROR', index=2, number=1001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_COMPUTE_ERROR', index=3, number=1002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_ESTOP_ERROR', index=4, number=1003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERFECT_CONTROL_ERROR', index=5, number=1004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANBUS_ERROR', index=6, number=2000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_CLIENT_ERROR_BASE', index=7, number=2100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_CLIENT_ERROR_OPEN_DEVICE_FAILED', index=8, number=2101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_CLIENT_ERROR_FRAME_NUM', index=9, number=2102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_CLIENT_ERROR_SEND_FAILED', index=10, number=2103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_CLIENT_ERROR_RECV_FAILED', index=11, number=2104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_ERROR', index=12, number=3000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_ERROR_MSG', index=13, number=3100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_ERROR_LIDAR', index=14, number=3200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_ERROR_INTEG', index=15, number=3300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCALIZATION_ERROR_GNSS', index=16, number=3400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_ERROR', index=17, number=4000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_ERROR_TF', index=18, number=4001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_ERROR_PROCESS', index=19, number=4002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_FATAL', index=20, number=4003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_ERROR_NONE', index=21, number=4004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION_ERROR_UNKNOWN', index=22, number=4005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREDICTION_ERROR', index=23, number=5000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANNING_ERROR', index=24, number=6000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANNING_ERROR_NOT_READY', index=25, number=6001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HDMAP_DATA_ERROR', index=26, number=7000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING_ERROR', index=27, number=8000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING_ERROR_REQUEST', index=28, number=8001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING_ERROR_RESPONSE', index=29, number=8002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTING_ERROR_NOT_READY', index=30, number=8003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='END_OF_INPUT', index=31, number=9000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_LOGIC_ERROR', index=32, number=10000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_RUNTIME_ERROR', index=33, number=10001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_MAP_ERROR', index=34, number=11000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_MAP_NOT_READY', index=35, number=11001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVER_ERROR_GNSS', index=36, number=12000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVER_ERROR_VELODYNE', index=37, number=13000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORYTELLING_ERROR', index=38, number=14000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=132,
  serialized_end=1181,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
OK = 0
CONTROL_ERROR = 1000
CONTROL_INIT_ERROR = 1001
CONTROL_COMPUTE_ERROR = 1002
CONTROL_ESTOP_ERROR = 1003
PERFECT_CONTROL_ERROR = 1004
CANBUS_ERROR = 2000
CAN_CLIENT_ERROR_BASE = 2100
CAN_CLIENT_ERROR_OPEN_DEVICE_FAILED = 2101
CAN_CLIENT_ERROR_FRAME_NUM = 2102
CAN_CLIENT_ERROR_SEND_FAILED = 2103
CAN_CLIENT_ERROR_RECV_FAILED = 2104
LOCALIZATION_ERROR = 3000
LOCALIZATION_ERROR_MSG = 3100
LOCALIZATION_ERROR_LIDAR = 3200
LOCALIZATION_ERROR_INTEG = 3300
LOCALIZATION_ERROR_GNSS = 3400
PERCEPTION_ERROR = 4000
PERCEPTION_ERROR_TF = 4001
PERCEPTION_ERROR_PROCESS = 4002
PERCEPTION_FATAL = 4003
PERCEPTION_ERROR_NONE = 4004
PERCEPTION_ERROR_UNKNOWN = 4005
PREDICTION_ERROR = 5000
PLANNING_ERROR = 6000
PLANNING_ERROR_NOT_READY = 6001
HDMAP_DATA_ERROR = 7000
ROUTING_ERROR = 8000
ROUTING_ERROR_REQUEST = 8001
ROUTING_ERROR_RESPONSE = 8002
ROUTING_ERROR_NOT_READY = 8003
END_OF_INPUT = 9000
HTTP_LOGIC_ERROR = 10000
HTTP_RUNTIME_ERROR = 10001
RELATIVE_MAP_ERROR = 11000
RELATIVE_MAP_NOT_READY = 11001
DRIVER_ERROR_GNSS = 12000
DRIVER_ERROR_VELODYNE = 13000
STORYTELLING_ERROR = 14000



_STATUSPB = _descriptor.Descriptor(
  name='StatusPb',
  full_name='apollo.common.StatusPb',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.common.StatusPb.error_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='apollo.common.StatusPb.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=129,
)

_STATUSPB.fields_by_name['error_code'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['StatusPb'] = _STATUSPB
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusPb = _reflection.GeneratedProtocolMessageType('StatusPb', (_message.Message,), {
  'DESCRIPTOR' : _STATUSPB,
  '__module__' : 'modules.common.proto.error_code_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.StatusPb)
  })
_sym_db.RegisterMessage(StatusPb)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/radar/ultrasonic_radar/proto/ultrasonic_radar_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.canbus.proto import can_card_parameter_pb2 as modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/radar/ultrasonic_radar/proto/ultrasonic_radar_conf.proto',
  package='apollo.drivers.ultrasonic_radar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHmodules/drivers/radar/ultrasonic_radar/proto/ultrasonic_radar_conf.proto\x12\x1f\x61pollo.drivers.ultrasonic_radar\x1a\x35modules/drivers/canbus/proto/can_card_parameter.proto\"\xb6\x01\n\x07\x43\x61nConf\x12\x43\n\x12\x63\x61n_card_parameter\x18\x01 \x01(\x0b\x32\'.apollo.drivers.canbus.CANCardParameter\x12 \n\x11\x65nable_debug_mode\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\"\n\x13\x65nable_receiver_log\x18\x03 \x01(\x08:\x05\x66\x61lse\x12 \n\x11\x65nable_sender_log\x18\x04 \x01(\x08:\x05\x66\x61lse\"g\n\x13UltrasonicRadarConf\x12:\n\x08\x63\x61n_conf\x18\x01 \x01(\x0b\x32(.apollo.drivers.ultrasonic_radar.CanConf\x12\x14\n\x0c\x65ntrance_num\x18\x02 \x01(\x05'
  ,
  dependencies=[modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2.DESCRIPTOR,])




_CANCONF = _descriptor.Descriptor(
  name='CanConf',
  full_name='apollo.drivers.ultrasonic_radar.CanConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_card_parameter', full_name='apollo.drivers.ultrasonic_radar.CanConf.can_card_parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_debug_mode', full_name='apollo.drivers.ultrasonic_radar.CanConf.enable_debug_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_receiver_log', full_name='apollo.drivers.ultrasonic_radar.CanConf.enable_receiver_log', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_sender_log', full_name='apollo.drivers.ultrasonic_radar.CanConf.enable_sender_log', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=347,
)


_ULTRASONICRADARCONF = _descriptor.Descriptor(
  name='UltrasonicRadarConf',
  full_name='apollo.drivers.ultrasonic_radar.UltrasonicRadarConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_conf', full_name='apollo.drivers.ultrasonic_radar.UltrasonicRadarConf.can_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entrance_num', full_name='apollo.drivers.ultrasonic_radar.UltrasonicRadarConf.entrance_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=452,
)

_CANCONF.fields_by_name['can_card_parameter'].message_type = modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2._CANCARDPARAMETER
_ULTRASONICRADARCONF.fields_by_name['can_conf'].message_type = _CANCONF
DESCRIPTOR.message_types_by_name['CanConf'] = _CANCONF
DESCRIPTOR.message_types_by_name['UltrasonicRadarConf'] = _ULTRASONICRADARCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CanConf = _reflection.GeneratedProtocolMessageType('CanConf', (_message.Message,), {
  'DESCRIPTOR' : _CANCONF,
  '__module__' : 'modules.drivers.radar.ultrasonic_radar.proto.ultrasonic_radar_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.ultrasonic_radar.CanConf)
  })
_sym_db.RegisterMessage(CanConf)

UltrasonicRadarConf = _reflection.GeneratedProtocolMessageType('UltrasonicRadarConf', (_message.Message,), {
  'DESCRIPTOR' : _ULTRASONICRADARCONF,
  '__module__' : 'modules.drivers.radar.ultrasonic_radar.proto.ultrasonic_radar_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.ultrasonic_radar.UltrasonicRadarConf)
  })
_sym_db.RegisterMessage(UltrasonicRadarConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/trafficlights_perception_component.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/trafficlights_perception_component.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nImodules/perception/onboard/proto/trafficlights_perception_component.proto\x12\x19\x61pollo.perception.onboard\"\xe0\x07\n\x0cTrafficLight\x12\x1e\n\x0ftl_tf2_frame_id\x18\x01 \x01(\t:\x05world\x12<\n\x15tl_tf2_child_frame_id\x18\x02 \x01(\t:\x1dperception_localization_100hz\x12 \n\x12tf2_timeout_second\x18\x03 \x01(\x01:\x04\x30.01\x12*\n\x0c\x63\x61mera_names\x18\x04 \x01(\t:\x14\x66ront_6mm,front_12mm\x12^\n\x14\x63\x61mera_channel_names\x18\x05 \x01(\t:@/apollo/sensor/camera/front_6mm,/apollo/sensor/camera/front_12mm\x12$\n\x19tl_image_timestamp_offset\x18\x06 \x01(\x01:\x01\x30\x12 \n\x15max_process_image_fps\x18\x07 \x01(\x05:\x01\x38\x12&\n\x19query_tf_interval_seconds\x18\x08 \x01(\x01:\x03\x30.3\x12!\n\x14valid_hdmap_interval\x18\t \x01(\x01:\x03\x31.5\x12(\n\x1bimage_sys_ts_diff_threshold\x18\n \x01(\x01:\x03\x30.5\x12\"\n\x15sync_interval_seconds\x18\x0b \x01(\x01:\x03\x30.5\x12H\n(camera_traffic_light_perception_conf_dir\x18\x0c \x01(\t:\x16\x63onf/perception/camera\x12\x42\n)camera_traffic_light_perception_conf_file\x18\r \x01(\t:\x0ftrafficlight.pt\x12&\n\x19\x64\x65\x66\x61ult_image_border_size\x18\x0e \x01(\x05:\x03\x31\x30\x30\x12K\n!traffic_light_output_channel_name\x18\x0f \x01(\t: /apollo/perception/traffic_light\x12L\n\x17simulation_channel_name\x18\x10 \x01(\t:+/apollo/perception/traffic_light_simulation\x12G\n$v2x_trafficlights_input_channel_name\x18\x11 \x01(\t:\x19/apollo/v2x/traffic_light\x12&\n\x19v2x_sync_interval_seconds\x18\x12 \x01(\x01:\x03\x30.1\x12!\n\x15max_v2x_msg_buff_size\x18\x13 \x01(\x05:\x02\x35\x30'
)




_TRAFFICLIGHT = _descriptor.Descriptor(
  name='TrafficLight',
  full_name='apollo.perception.onboard.TrafficLight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tl_tf2_frame_id', full_name='apollo.perception.onboard.TrafficLight.tl_tf2_frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"world".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tl_tf2_child_frame_id', full_name='apollo.perception.onboard.TrafficLight.tl_tf2_child_frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"perception_localization_100hz".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tf2_timeout_second', full_name='apollo.perception.onboard.TrafficLight.tf2_timeout_second', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.01),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_names', full_name='apollo.perception.onboard.TrafficLight.camera_names', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm,front_12mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_channel_names', full_name='apollo.perception.onboard.TrafficLight.camera_channel_names', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/sensor/camera/front_6mm,/apollo/sensor/camera/front_12mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tl_image_timestamp_offset', full_name='apollo.perception.onboard.TrafficLight.tl_image_timestamp_offset', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_process_image_fps', full_name='apollo.perception.onboard.TrafficLight.max_process_image_fps', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=8,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_tf_interval_seconds', full_name='apollo.perception.onboard.TrafficLight.query_tf_interval_seconds', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_hdmap_interval', full_name='apollo.perception.onboard.TrafficLight.valid_hdmap_interval', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_sys_ts_diff_threshold', full_name='apollo.perception.onboard.TrafficLight.image_sys_ts_diff_threshold', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sync_interval_seconds', full_name='apollo.perception.onboard.TrafficLight.sync_interval_seconds', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_traffic_light_perception_conf_dir', full_name='apollo.perception.onboard.TrafficLight.camera_traffic_light_perception_conf_dir', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"conf/perception/camera".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_traffic_light_perception_conf_file', full_name='apollo.perception.onboard.TrafficLight.camera_traffic_light_perception_conf_file', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"trafficlight.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_image_border_size', full_name='apollo.perception.onboard.TrafficLight.default_image_border_size', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_output_channel_name', full_name='apollo.perception.onboard.TrafficLight.traffic_light_output_channel_name', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/perception/traffic_light".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulation_channel_name', full_name='apollo.perception.onboard.TrafficLight.simulation_channel_name', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/perception/traffic_light_simulation".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2x_trafficlights_input_channel_name', full_name='apollo.perception.onboard.TrafficLight.v2x_trafficlights_input_channel_name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/v2x/traffic_light".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2x_sync_interval_seconds', full_name='apollo.perception.onboard.TrafficLight.v2x_sync_interval_seconds', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_v2x_msg_buff_size', full_name='apollo.perception.onboard.TrafficLight.max_v2x_msg_buff_size', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=50,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=1097,
)

DESCRIPTOR.message_types_by_name['TrafficLight'] = _TRAFFICLIGHT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrafficLight = _reflection.GeneratedProtocolMessageType('TrafficLight', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHT,
  '__module__' : 'modules.perception.onboard.proto.trafficlights_perception_component_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.TrafficLight)
  })
_sym_db.RegisterMessage(TrafficLight)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/pad_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/pad_msg.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/planning/proto/pad_msg.proto\x12\x0f\x61pollo.planning\x1a!modules/common/proto/header.proto\"c\n\nPadMessage\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.apollo.planning.DrivingAction*t\n\rDrivingAction\x12\x08\n\x04NONE\x10\x64\x12\n\n\x06\x46OLLOW\x10\x00\x12\x0f\n\x0b\x43HANGE_LEFT\x10\x01\x12\x10\n\x0c\x43HANGE_RIGHT\x10\x02\x12\r\n\tPULL_OVER\x10\x03\x12\x08\n\x04STOP\x10\x04\x12\x11\n\rRESUME_CRUISE\x10\x05'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])

_DRIVINGACTION = _descriptor.EnumDescriptor(
  name='DrivingAction',
  full_name='apollo.planning.DrivingAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOLLOW', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_LEFT', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_RIGHT', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESUME_CRUISE', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=193,
  serialized_end=309,
)
_sym_db.RegisterEnumDescriptor(_DRIVINGACTION)

DrivingAction = enum_type_wrapper.EnumTypeWrapper(_DRIVINGACTION)
NONE = 100
FOLLOW = 0
CHANGE_LEFT = 1
CHANGE_RIGHT = 2
PULL_OVER = 3
STOP = 4
RESUME_CRUISE = 5



_PADMESSAGE = _descriptor.Descriptor(
  name='PadMessage',
  full_name='apollo.planning.PadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.planning.PadMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='apollo.planning.PadMessage.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=191,
)

_PADMESSAGE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PADMESSAGE.fields_by_name['action'].enum_type = _DRIVINGACTION
DESCRIPTOR.message_types_by_name['PadMessage'] = _PADMESSAGE
DESCRIPTOR.enum_types_by_name['DrivingAction'] = _DRIVINGACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PadMessage = _reflection.GeneratedProtocolMessageType('PadMessage', (_message.Message,), {
  'DESCRIPTOR' : _PADMESSAGE,
  '__module__' : 'modules.planning.proto.pad_msg_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PadMessage)
  })
_sym_db.RegisterMessage(PadMessage)


# @@protoc_insertion_point(module_scope)
